@@ -1,12 +1,12 @@
 import re
-import gzip
 import hmac
 import base64
 import hashlib
 import binascii
 import urllib.parse
-from Crypto.Cipher import DES3, AES, DES
+from contextlib import suppress
 from Crypto.Util.Padding import unpad
+from Crypto.Cipher import DES3, AES, DES
 from badsecrets.helpers import Java_sha1prng
 from badsecrets.base import BadsecretsBase
 
@@ -25,14 +25,6 @@ class Jsf_viewstate(BadsecretsBase):
 
     hashcat_hashalg_table = {"MD5": "50", "SHA1": "150", "SHA256": "1450", "SHA384": "10800", "SHA512": "1750"}
 
-    @staticmethod
-    def attempt_decompress(value):
-        try:
-            uncompressed = gzip.decompress(base64.b64decode(value))
-        except (gzip.BadGzipFile, binascii.Error, ValueError):
-            return False
-        return uncompressed
-
     def carve_regex(self):
         return re.compile(r"<input.+?name=\"javax\.faces\.ViewState\".+?value=\"([^\"]*)\"")
 
@@ -184,7 +176,10 @@ class Jsf_viewstate(BadsecretsBase):
 
     def get_hashcat_commands(self, jsf_viewstate_value, *args):
         commands = []
-        decoded_viewstate = base64.b64decode(urllib.parse.unquote(jsf_viewstate_value))
+        try:
+            decoded_viewstate = base64.b64decode(urllib.parse.unquote(jsf_viewstate_value))
+        except binascii.Error:
+            return []
         sig = decoded_viewstate[:32]
         data = decoded_viewstate[32:]
 
@@ -238,40 +233,42 @@ class Jsf_viewstate(BadsecretsBase):
             else:
                 jsf_viewstate_value = base64.b64encode(uncompressed)
 
-        for l in set(list(self.load_resources(["jsf_viewstate_passwords.txt", "top_10000_passwords.txt"]))):
-            password = l.rstrip()
-            if self.DES3_decrypt(jsf_viewstate_value, password):
-                return {
-                    "secret": password,
-                    "details": {
-                        "source": jsf_viewstate_value,
-                        "info": "JSF Viewstate (Mojarra 1.2.x - 2.0.3) 3DES Encrypted",
-                        "compression": True if uncompressed else False,
-                    },
-                }
-
-        # Mojarra decryption
-        for l in self.load_resources(["jsf_viewstate_passwords_b64.txt"]):
-            password_bytes = base64.b64decode(l.rstrip())
-            decrypted = self.AES_decrypt(jsf_viewstate_value, password_bytes)
-
-            if decrypted:
-                uncompressed = self.attempt_decompress(base64.b64encode(decrypted))
-                if uncompressed:
-                    if b"java." in uncompressed:
-                        decrypted = uncompressed
-
-                decrypted_b64 = base64.b64encode(decrypted).decode()
-                if decrypted_b64.startswith("rO0"):
+        for l in set(list(self.load_resources(["jsf_viewstate_passwords.txt", "top_100000_passwords.txt"]))):
+            with suppress(ValueError):
+                password = l.rstrip()
+                if self.DES3_decrypt(jsf_viewstate_value, password):
                     return {
-                        "secret": base64.b64encode(password_bytes).decode(),
+                        "secret": password,
                         "details": {
                             "source": jsf_viewstate_value,
-                            "info": "JSF Viewstate (Mojarra 2.2.6 - 2.3.x) AES Encrypted",
+                            "info": "JSF Viewstate (Mojarra 1.2.x - 2.0.3) 3DES Encrypted",
                             "compression": True if uncompressed else False,
                         },
                     }
 
+        # Mojarra decryption
+        for l in self.load_resources(["jsf_viewstate_passwords_b64.txt"]):
+            with suppress(ValueError):
+                password_bytes = base64.b64decode(l.rstrip())
+                decrypted = self.AES_decrypt(jsf_viewstate_value, password_bytes)
+
+                if decrypted:
+                    uncompressed = self.attempt_decompress(base64.b64encode(decrypted))
+                    if uncompressed:
+                        if b"java." in uncompressed:
+                            decrypted = uncompressed
+
+                    decrypted_b64 = base64.b64encode(decrypted).decode()
+                    if decrypted_b64.startswith("rO0"):
+                        return {
+                            "secret": base64.b64encode(password_bytes).decode(),
+                            "details": {
+                                "source": jsf_viewstate_value,
+                                "info": "JSF Viewstate (Mojarra 2.2.6 - 2.3.x) AES Encrypted",
+                                "compression": True if uncompressed else False,
+                            },
+                        }
+
         # myfaces decryption / mac
 
         myfaces_solved_mac_key = None
@@ -288,10 +285,11 @@ class Jsf_viewstate(BadsecretsBase):
 
         # Attempt to solve mac_key
         for l in self.load_resources(["jsf_viewstate_passwords_b64.txt"]):
-            password_bytes = base64.b64decode(l.rstrip())
-            myfaces_solved_mac_key, myfaces_solved_mac_algo = self.myfaces_mac(ct_bytes, password_bytes)
-            if myfaces_solved_mac_key:
-                break
+            with suppress(ValueError):
+                password_bytes = base64.b64decode(l.rstrip())
+                myfaces_solved_mac_key, myfaces_solved_mac_algo = self.myfaces_mac(ct_bytes, password_bytes)
+                if myfaces_solved_mac_key:
+                    break
 
         # Attempt to solve encryption_key
         dec_algos = set()
@@ -306,16 +304,17 @@ class Jsf_viewstate(BadsecretsBase):
             hash_sizes = self.hash_sizes.values()
 
         for l in self.load_resources(["jsf_viewstate_passwords_b64.txt"]):
-            password_bytes = base64.b64decode(l.rstrip())
-            (
-                myfaces_solved_decryption_key,
-                myfaces_solved_decryption_algo,
-                myfaces_solved_decryption_mode,
-                myfaces_solved_decryption_iv,
-                compression,
-            ) = self.myfaces_decrypt(ct_bytes, password_bytes, dec_algos, hash_sizes)
-            if myfaces_solved_decryption_key:
-                break
+            with suppress(ValueError):
+                password_bytes = base64.b64decode(l.rstrip())
+                (
+                    myfaces_solved_decryption_key,
+                    myfaces_solved_decryption_algo,
+                    myfaces_solved_decryption_mode,
+                    myfaces_solved_decryption_iv,
+                    compression,
+                ) = self.myfaces_decrypt(ct_bytes, password_bytes, dec_algos, hash_sizes)
+                if myfaces_solved_decryption_key:
+                    break
 
         if myfaces_solved_mac_key or myfaces_solved_decryption_key:
             if myfaces_solved_decryption_key:
